# **Redis-yy, designed by yy**

## Installing and Getting started

1. Install

    The easiest way to install.
    
    ```py
    pip install redis-yy
    ```
  
    Or you can clone source code from github.
  
    ```bash
    git clone git@github.com:guaidashu/redis_yy.git
    ```

3. Start

    Example
        
    ```py
    from redis_yy import RedisDB
            
    redis = RedisDB(host="127.0.0.1", port="6372")
    ```

## Usage

None

## FAQ

None

## Running Tests

## Finally Thanks 

Thanks for your support.